Geometry
========

.. autoclass:: pancad.abstract.AbstractGeometry
    :show-inheritance:
    :members:

.. autoclass:: pancad.abstract.AbstractGeometrySystem
    :show-inheritance:
    :members:

.. autoclass:: pancad.api.Circle
    :show-inheritance:
    :members:

.. autoclass:: pancad.api.CircularArc
    :show-inheritance:
    :members:

.. autoclass:: pancad.api.CoordinateSystem
    :show-inheritance:
    :members:

.. autoclass:: pancad.api.Ellipse
    :show-inheritance:
    :members:

.. autoclass:: pancad.api.Line
    :show-inheritance:
    :members:

.. autoclass:: pancad.api.LineSegment
    :show-inheritance:
    :members:

.. autoclass:: pancad.api.Point
    :show-inheritance:
    :members:

.. autoclass:: pancad.api.FeatureSystem
    :show-inheritance:
    :members:

.. autoclass:: pancad.api.SketchGeometrySystem
    :show-inheritance:
    :members:

.. autoclass:: pancad.api.TwoDSketchSystem
    :show-inheritance:
    :members:

.. autoclass:: pancad.api.ThreeDSketchSystem
    :show-inheritance:
    :members:

Enumerations
------------

.. autoclass:: pancad.api.ConstraintReference
    :show-inheritance:
    :members:
